@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: criterion
 version: 1.1.1.0
-id: criterion-1.1.1.0-d3f1d7734d0ec550847f9a7a12a47a1f
-key: crite_24SS7YhlikZ0kmnOTaym4x
+id: criterion-1.1.1.0-428040a5db30613d2382f9b99f29122a
+key: crite_E4NO6bWn0dd4phHi804fVs
 license: BSD3
 copyright: 2009-2014 Bryan O'\''Sullivan
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -35,7 +35,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/criterion-1.1.1.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/criterion-1.1.1.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/criterion-1.1.1.0
-hs-libraries: HScriterion-1.1.1.0-24SS7YhlikZ0kmnOTaym4x
+hs-libraries: HScriterion-1.1.1.0-E4NO6bWn0dd4phHi804fVs
 depends:
     Glob-0.7.5-2de4d761061e270a9c358a45d1e533d4
     aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
@@ -53,7 +53,7 @@ depends:
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
-    statistics-0.13.2.3-fb2d29ac22ccabf2cfd4165df330c05e
+    statistics-0.13.2.3-ea8e7d1808ba456bb62cfdee2801b88f
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
